@@ -1,6 +1,7 @@
 import os.path
 from pathlib import Path
-from . import settings
+from .settings import get_scopes
+# from settings import get_scopes
 
 from google_auth_oauthlib.flow import InstalledAppFlow
 from google.auth.transport.requests import Request
@@ -16,7 +17,7 @@ class Auth:
         if not creds:
             try:
                 flow = InstalledAppFlow.from_client_secrets_file(
-                    'credentials.json', settings.get_scopes())
+                    'credentials.json', get_scopes())
                 creds = flow.run_console()
 
                 # save the credentials        
@@ -37,7 +38,7 @@ class Auth:
         os.chdir(os.path.expanduser('~') + '/.comcomdrive')
 
         if os.path.exists('token.json'):
-            creds = Credentials.from_authorized_user_file('token.json', settings.get_scopes())
+            creds = Credentials.from_authorized_user_file('token.json', get_scopes())
 
         if creds and not creds.valid:
             if creds.expired and creds.refresh_token:
